RefString

Struct RefString 

pub struct RefString(/* private fields */);
A weak reference to a garbage collected, interned string.

Implementations

Source

impl RefString

pub fn new<'a>(s: impl Into<Cow<'a, str>>) -> Self

Returns a reference to a garbage collected string that contains s.

If another RootString or RefString exists already with the same contents as s, it will be returned and s will be dropped.

pub fn from_any(any: AnyRef) -> Option<Self>

Upgrades a typeless reference to a pooled string reference.

Returns None if any is not a pooled string.

pub fn load<'guard>( &self, guard: &'guard CollectionGuard<'_>, ) -> Option<&'guard str>

Loads a reference to the underlying string, if the string hasn’t been freed.

pub fn as_root(&self, guard: &CollectionGuard<'_>) -> Option<RootString>

Loads this string as a root, if the string hasn’t been freed.

pub fn as_any(&self) -> AnyRef

Returns a typeless reference to this string.